@@ -18,7 +18,9 @@
 #'
 #' @examples
 #' ranktransform(c(0, 1, 5, -5, -2))
-#' ranktransform(c(0, 1, 5, -5, -2), sign = TRUE)
+#'
+#' # Won't work
+#' # ranktransform(c(0, 1, 5, -5, -2), sign = TRUE)
 #'
 #' head(ranktransform(trees))
 #' @return A rank-transformed object.
@@ -45,7 +47,7 @@ ranktransform.numeric <- function(x,
   }
 
   # Warning if only one value and return early
-  if (length(unique(x)) == 1L) {
+  if (insight::has_single_value(x)) {
     if (is.null(names(x))) {
       name <- deparse(substitute(x))
     } else {
