@@ -122,3 +122,19 @@ test_that(".select_nse: misc", {
     "Sepal.Width"
   )
 })
+
+test_that(".select_nse: works with function and namespace", {
+  model <- lm(Petal.Length ~ Petal.Width, data = iris)
+  out <- data_select(iris, insight::find_predictors(model, effects = "fixed", flatten = TRUE))
+  expect_identical(out, iris["Petal.Width"])
+
+  fun <- function(x) {
+    data_select(iris, x)
+  }
+  out <- fun(insight::find_predictors(model, effects = "fixed", flatten = TRUE))
+  expect_identical(out, iris["Petal.Width"])
+
+  x <- "Sepal.Length"
+  out <- fun(insight::find_predictors(model, effects = "fixed", flatten = TRUE))
+  expect_identical(out, iris["Petal.Width"])
+})
